==> chmpy_sp-0.2.0.tar.gz: chmpy_sp-0.2.0/README.md <==
# **CHMpy-sp** ![PyPI - Version](https://img.shields.io/pypi/v/chmpy_sp.svg)  ![License](https://img.shields.io/github/license/AmmarSyamil/chmpy)

**CHMpy-sp is a python TUI made from Textual for changing file/folder permission in Linux easily. It target for user who is still a beginner using Linux and want to change a file/folder permission without manualy using chmod command.**

---

## Table of Contents

- [Installation](#installation)  
- [Usage](#usage)  
- [Dependencies / Requirements](#dependencies‑requirements)  
- [Features](#features)  
- [Contributing](#contributing)  
- [License](#license)  
- [Author / Maintainer](#author‑maintainer)
- [Citation](#Citation)

---

## Installation

```bash
pip install pip install chmpy-sp
# or from GitHub:
pip install git+https://github.com/AmmarSyamil/CHMpy.git
```
## Usage
```bash
#type in terminal to start the TUI
chmpy-sp
```

## Dependencies / Requirements
- Python 3.8 or higher
- Textual 0.74.0 or higher
- Art 6.5 or higher

## Features
- Change file/folder permission using TUI.
- See the tree project structure.

## Contributing
 Report bugs or suggest features via [Github Issues](https://github.com/AmmarSyamil/CHMpy/issues).

## License
This project is under
[MIT License](https://github.com/AmmarSyamil/CHMpy/blob/main/LICENSE).

## Author / Maintainer
Ammar Syaamil (@AmmarSyamil)
E-mail: ammarsyamil057@gmail.com

## Citation
If you use this project in your work, please cite it as:

Ammar, Syamil. (2025). *CHMpy-sp* (v0.1.0). https://github.com/AmmarSyamil/CHMpy

==> chmpy_sp-0.2.8.tar.gz: chmpy_sp-0.2.8/README.md <==
# **CHMpy-sp** ![PyPI - Version](https://img.shields.io/pypi/v/chmpy_sp.svg)  ![License](https://img.shields.io/github/license/AmmarSyamil/chmpy)

**CHMpy-sp is a python TUI made from Textual for changing file/folder permission in Linux easily. It target for user who is still a beginner using Linux and want to change a file/folder permission without manualy using chmod command.**

---

## Table of Contents

- [Installation](#installation)  
- [Usage](#usage)  
- [Dependencies / Requirements](#dependencies‑requirements)  
- [Features](#features)  
- [Contributing](#contributing)  
- [License](#license)  
- [Author / Maintainer](#author‑maintainer)
- [Citation](#Citation)

---

## Installation

```bash
pip install chmpy-sp
# or from GitHub:
pip install git+https://github.com/AmmarSyamil/CHMpy.git
```
## Usage
```bash
#type in terminal to start the TUI
chmpy-sp
```

## Dependencies / Requirements
- Python 3.8 or higher
- Textual 0.74.0 or higher
- Art 6.5 or higher

## Features
- Change file/folder permission using TUI.
- See the tree project structure.

## Contributing
 Report bugs or suggest features via [Github Issues](https://github.com/AmmarSyamil/CHMpy/issues).

## License
This project is under
[MIT License](https://github.com/AmmarSyamil/CHMpy/blob/main/LICENSE).

## Author / Maintainer
Ammar Syaamil (@AmmarSyamil)
E-mail: ammarsyamil057@gmail.com

## Citation
If you use this project in your work, please cite it as:

Ammar, Syamil. (2025). *CHMpy-sp* (<version>). https://github.com/AmmarSyamil/CHMpy
